summaryrefslogtreecommitdiff
path: root/gold/symtab.h
diff options
context:
space:
mode:
authorIan Lance Taylor <iant@google.com>2007-10-14 06:49:14 +0000
committerIan Lance Taylor <iant@google.com>2007-10-14 06:49:14 +0000
commitb1927b0c56a30b2e8b64b5ffae3e41dfb601f0b1 (patch)
treecf12129ecd040e6c6f3669896f2d814f9c264345 /gold/symtab.h
parentab54a8dce4d7b21b05f8a22f9a567dc655a3a927 (diff)
downloadbinutils-redhat-b1927b0c56a30b2e8b64b5ffae3e41dfb601f0b1.tar.gz
Run all error handling through an Errors object. Delete output file
on error.
Diffstat (limited to 'gold/symtab.h')
-rw-r--r--gold/symtab.h13
1 files changed, 9 insertions, 4 deletions
diff --git a/gold/symtab.h b/gold/symtab.h
index 0dabd517d1..58c0e50ccf 100644
--- a/gold/symtab.h
+++ b/gold/symtab.h
@@ -728,9 +728,11 @@ class Warnings
void
note_warnings(Symbol_table* symtab);
- // Issue a warning for a reference to SYM at LOCATION.
+ // Issue a warning for a reference to SYM at RELINFO's location.
+ template<int size, bool big_endian>
void
- issue_warning(const Symbol* sym, const std::string& location) const;
+ issue_warning(const Symbol* sym, const Relocate_info<size, big_endian>*,
+ size_t relnum, off_t reloffset) const;
private:
Warnings(const Warnings&);
@@ -876,9 +878,12 @@ class Symbol_table
// Possibly issue a warning for a reference to SYM at LOCATION which
// is in OBJ.
+ template<int size, bool big_endian>
void
- issue_warning(const Symbol* sym, const std::string& location) const
- { this->warnings_.issue_warning(sym, location); }
+ issue_warning(const Symbol* sym,
+ const Relocate_info<size, big_endian>* relinfo,
+ size_t relnum, off_t reloffset) const
+ { this->warnings_.issue_warning(sym, relinfo, relnum, reloffset); }
// Set the dynamic symbol indexes. INDEX is the index of the first
// global dynamic symbol. Pointers to the symbols are stored into